@@ -11,7 +11,7 @@
 /// \endverbatim
 
 //----------------------------------------------------------------------
-// $Id: example_dpsi_collinear.cc 1407 2024-02-28 12:57:35Z gsoyez $
+// $Id: example_dpsi_collinear.cc 1465 2024-12-11 14:53:28Z gsoyez $
 //
 // Copyright (c) 2018-, Frederic A. Dreyer, Keith Hamilton, Alexander Karlberg,
 // Gavin P. Salam, Ludovic Scyboz, Gregory Soyez, Rob Verheyen
@@ -41,7 +41,8 @@
 #include "fastjet/PseudoJet.hh"
 #include "fastjet/EECambridgePlugin.hh"
 #include <string>
-#include "RecursiveLundEEGenerator.hh" // In external code, this should be fastjet/contrib/RecursiveLundEEGenerator.hh
+#include "fastjet/contrib/RecursiveLundEEGenerator.hh"
+
 using namespace std;
 using namespace fastjet;
 
