@@ -7,7 +7,7 @@
 // Run this example with
 //     ./example_advanced_usage < ../data/single-event.dat
 //
-//  $Id: example_advanced_usage.cc 933 2016-04-04 22:23:32Z jthaler $
+//  $Id: example_advanced_usage.cc 1412 2024-02-29 00:15:59Z jthaler $
 //----------------------------------------------------------------------
 // This file is part of FastJet contrib.
 //
@@ -85,6 +85,7 @@ public:
    : _axes_def(myStruct._axes_def->create()) {}
    
    const AxesDefinition & def() const {return *_axes_def;}
+   AxesDefinition & def_for_change() {return *_axes_def;}
    string description() const {return _axes_def->description();}
    string short_description() const {return _axes_def->short_description();}
 
@@ -161,17 +162,21 @@ void analyze(const vector<PseudoJet> & input_particles) {
 
    // A list of all of the available axes modes
    vector<AxesStruct> _testAxes;
+   _testAxes.push_back(HalfKT_Axes());
    _testAxes.push_back(KT_Axes());
    _testAxes.push_back(CA_Axes());
    _testAxes.push_back(AntiKT_Axes(R0));
+   _testAxes.push_back(WTA_HalfKT_Axes());
    _testAxes.push_back(WTA_KT_Axes());
    _testAxes.push_back(WTA_CA_Axes());
    _testAxes.push_back(GenKT_Axes(p, R0));
    _testAxes.push_back(WTA_GenKT_Axes(p, R0));
    _testAxes.push_back(GenET_GenKT_Axes(delta, p, R0));
 
+   _testAxes.push_back(OnePass_HalfKT_Axes());
    _testAxes.push_back(OnePass_KT_Axes());
    _testAxes.push_back(OnePass_AntiKT_Axes(R0));
+   _testAxes.push_back(OnePass_WTA_HalfKT_Axes());
    _testAxes.push_back(OnePass_WTA_KT_Axes());
    _testAxes.push_back(OnePass_GenKT_Axes(p, R0));
    _testAxes.push_back(OnePass_WTA_GenKT_Axes(p, R0));
@@ -192,6 +197,14 @@ void analyze(const vector<PseudoJet> & input_particles) {
    _testAxes.push_back(MultiPass_Manual_Axes(NPass));
    int num_unchecked = 4; // number of unchecked axes
 
+   // For testing purposes on different platforms, increase number of iterations
+   // and accuracy for OnePass minimization to be less sensitive to floating point rounding
+   for (unsigned int i = 0; i < _testAxes.size(); i++) {
+      if (_testAxes[i].def().nPass() == 1) {
+         _testAxes[i].def_for_change().setNPass(1, 10000, 0.00001); // defaut is 1, 1000, 0.0001
+      }
+   }
+   
    //
    // Note:  Njettiness::min_axes is not guarenteed to give a global
    // minimum, only a local minimum, and different choices of the random
@@ -202,10 +215,8 @@ void analyze(const vector<PseudoJet> & input_particles) {
    // Getting a smaller list of recommended axes modes
    // These are the ones that are more likely to give sensible results (and are all IRC safe)
    vector<AxesStruct> _testRecommendedAxes;
-   _testRecommendedAxes.push_back(KT_Axes());
+   _testRecommendedAxes.push_back(HalfKT_Axes());
    _testRecommendedAxes.push_back(WTA_KT_Axes());
-   _testRecommendedAxes.push_back(OnePass_KT_Axes());
-   _testRecommendedAxes.push_back(OnePass_WTA_KT_Axes());
 
    // new axes options added in most recent version of Nsubjettiness
    // these are separate from above since they should only be defined with a cutoff value for sensible results
@@ -267,7 +278,7 @@ void analyze(const vector<PseudoJet> & input_particles) {
       cout << "-----------------------------------------------------------------------------------------------" << endl;
       cout << "Analyzing Jet " << j + 1 << ":" << endl;
       cout << "-----------------------------------------------------------------------------------------------" << endl;
-
+      
       
       ////////
       //
