@@ -1,4 +1,4 @@
-// $Id: RecursiveSoftDrop.cc 1192 2018-10-30 16:08:36Z gsoyez $
+// $Id: RecursiveSoftDrop.cc 1458 2024-12-11 08:25:19Z salam $
 //
 // Copyright (c) 2017-, Gavin P. Salam, Gregory Soyez, Jesse Thaler,
 // Kevin Zhou, Frederic Dreyer
@@ -20,7 +20,7 @@
 // along with this code. If not, see <http://www.gnu.org/licenses/>.
 //----------------------------------------------------------------------
 
-#include "RecursiveSoftDrop.hh"
+#include "fastjet/contrib/RecursiveSoftDrop.hh"
 #include "fastjet/ClusterSequence.hh"
 
 using namespace std;
