@@ -1,4 +1,4 @@
-// $Id: RecursiveSymmetryCutBase.cc 1281 2021-08-16 15:52:43Z salam $
+// $Id: RecursiveSymmetryCutBase.cc 1458 2024-12-11 08:25:19Z salam $
 //
 // Copyright (c) 2014-, Gavin P. Salam, Gregory Soyez, Jesse Thaler
 //
@@ -19,7 +19,7 @@
 // along with this code. If not, see <http://www.gnu.org/licenses/>.
 //----------------------------------------------------------------------
 
-#include "RecursiveSymmetryCutBase.hh"
+#include "fastjet/contrib/RecursiveSymmetryCutBase.hh"
 #include "fastjet/JetDefinition.hh"
 #include "fastjet/ClusterSequenceAreaBase.hh"
 #include <cassert>
