@@ -11,7 +11,7 @@
 /// \endverbatim
 //----------------------------------------------------------------------
 
-// $Id: example_recursive_softdrop.cc 1394 2024-02-26 13:36:35Z jthaler $
+// $Id: example_recursive_softdrop.cc 1458 2024-12-11 08:25:19Z salam $
 //
 // Copyright (c) 2017-, Gavin P. Salam, Gregory Soyez, Jesse Thaler,
 // Kevin Zhou, Frederic Dreyer
@@ -39,7 +39,7 @@
 #include <iomanip>
 #include <cmath>
 #include "fastjet/ClusterSequence.hh"
-#include "RecursiveSoftDrop.hh" // In external code, this should be fastjet/contrib/RecursiveSoftDrop.hh
+#include "fastjet/contrib/RecursiveSoftDrop.hh"
 
 using namespace std;
 using namespace fastjet;
